==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/TASKDYNAMICCHECKLISTID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TASKDYNAMICCHECKLISTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="TASKDYNAMICCHECKLISTID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TASKDYNAMICCHECKLISTCONDITIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DYNAMICCHECKLISTITEMID"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKDYNAMICCHECKLISTID_Type", propOrder = {
    "taskdynamicchecklistconditionid",
    "dynamicchecklistitemid"
})
public class TASKDYNAMICCHECKLISTID_Type {

    @XmlElement(name = "TASKDYNAMICCHECKLISTCONDITIONID", required = true)
    protected TASKDYNAMICCHECKLISTCONDITIONID_Type taskdynamicchecklistconditionid;
    @XmlElement(name = "DYNAMICCHECKLISTITEMID", required = true)
    protected CHECKLISTID_Type dynamicchecklistitemid;

    /**
     * Gets the value of the taskdynamicchecklistconditionid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKDYNAMICCHECKLISTCONDITIONID_Type }
     *     
     */
    public TASKDYNAMICCHECKLISTCONDITIONID_Type getTASKDYNAMICCHECKLISTCONDITIONID() {
        return taskdynamicchecklistconditionid;
    }

    /**
     * Sets the value of the taskdynamicchecklistconditionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKDYNAMICCHECKLISTCONDITIONID_Type }
     *     
     */
    public void setTASKDYNAMICCHECKLISTCONDITIONID(TASKDYNAMICCHECKLISTCONDITIONID_Type value) {
        this.taskdynamicchecklistconditionid = value;
    }

    /**
     * Gets the value of the dynamicchecklistitemid property.
     * 
     * @return
     *     possible object is
     *     {@link CHECKLISTID_Type }
     *     
     */
    public CHECKLISTID_Type getDYNAMICCHECKLISTITEMID() {
        return dynamicchecklistitemid;
    }

    /**
     * Sets the value of the dynamicchecklistitemid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CHECKLISTID_Type }
     *     
     */
    public void setDYNAMICCHECKLISTITEMID(CHECKLISTID_Type value) {
        this.dynamicchecklistitemid = value;
    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_fields/TASKDYNAMICCHECKLISTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TASKDYNAMICCHECKLISTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TASKDYNAMICCHECKLISTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKDYNAMICCHECKLISTCONDITIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DYNAMICCHECKLISTITEMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKDYNAMICCHECKLISTID_Type", propOrder = {
    "taskdynamicchecklistconditionid",
    "dynamicchecklistitemid"
})
public class TASKDYNAMICCHECKLISTID_Type {

    @XmlElement(name = "TASKDYNAMICCHECKLISTCONDITIONID", required = true)
    protected TASKDYNAMICCHECKLISTCONDITIONID_Type taskdynamicchecklistconditionid;
    @XmlElement(name = "DYNAMICCHECKLISTITEMID", required = true)
    protected CHECKLISTID_Type dynamicchecklistitemid;

    /**
     * Gets the value of the taskdynamicchecklistconditionid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKDYNAMICCHECKLISTCONDITIONID_Type }
     *     
     */
    public TASKDYNAMICCHECKLISTCONDITIONID_Type getTASKDYNAMICCHECKLISTCONDITIONID() {
        return taskdynamicchecklistconditionid;
    }

    /**
     * Sets the value of the taskdynamicchecklistconditionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKDYNAMICCHECKLISTCONDITIONID_Type }
     *     
     */
    public void setTASKDYNAMICCHECKLISTCONDITIONID(TASKDYNAMICCHECKLISTCONDITIONID_Type value) {
        this.taskdynamicchecklistconditionid = value;
    }

    /**
     * Gets the value of the dynamicchecklistitemid property.
     * 
     * @return
     *     possible object is
     *     {@link CHECKLISTID_Type }
     *     
     */
    public CHECKLISTID_Type getDYNAMICCHECKLISTITEMID() {
        return dynamicchecklistitemid;
    }

    /**
     * Sets the value of the dynamicchecklistitemid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CHECKLISTID_Type }
     *     
     */
    public void setDYNAMICCHECKLISTITEMID(CHECKLISTID_Type value) {
        this.dynamicchecklistitemid = value;
    }

}
